<?php

namespace Drupal\commerce_inventory\Form;

use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Entity\EntityConstraintViolationListInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form controller for Inventory Item edit forms.
 *
 * @ingroup commerce_inventory
 */
class InventoryItemForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    /* @var $entity \Drupal\commerce_inventory\Entity\InventoryItem */
    $form = parent::buildForm($form, $form_state);
    $form['#attached']['library'][] = 'core_extend/form';
    $form['#theme'] = ['entity_edit_form'];
    $entity = $this->entity;

    // Create advanced tabs section.
    $form['advanced'] = [
      '#attributes' => ['class' => ['entity-meta']],
      '#type' => 'container',
      '#weight' => 99,
    ];

    if (!$entity->isNew()) {

      $form['meta'] = [
        '#group' => 'advanced',
        '#weight' => -100,
        '#attributes' => ['class' => ['entity-meta__header']],
        '#type' => 'container',
      ];

      // @todo move these into advanced
      if (array_key_exists('location_id', $form)) {
        $form['location_id']['#disabled'] = TRUE;
      }

      if (array_key_exists('purchasable_entity', $form)) {
        $form['purchasable_entity']['#disabled'] = TRUE;
      }
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  protected function flagViolations(EntityConstraintViolationListInterface $violations, array $form, FormStateInterface $form_state) {
    /* @var $entity \Drupal\commerce_inventory\Entity\InventoryItem */
    $entity = $violations->getEntity();

    // Manually flag violations of fields not handled by the form display. This
    // is necessary as entity form displays only flag violations for fields
    // contained in the display.
    if ($entity->isNew()) {
      $field_names = [
        'location_id',
        'purchasable_entity',
      ];
      foreach ($violations->getByFields($field_names) as $violation) {
        list($field_name) = explode('.', $violation->getPropertyPath(), 2);
        $form_state->setErrorByName($field_name, $violation->getMessage());
      }
    }

    parent::flagViolations($violations, $form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $entity = &$this->entity;

    $status = parent::save($form, $form_state);

    switch ($status) {
      case SAVED_NEW:
        drupal_set_message($this->t('Created the %label Inventory Item.', [
          '%label' => $entity->label(),
        ]));
        break;

      default:
        drupal_set_message($this->t('Saved the %label Inventory Item.', [
          '%label' => $entity->label(),
        ]));
    }
    $form_state->setRedirectUrl($entity->toUrl());
  }

}
